function [x,y,absyhx] = rpzCompatible(x,y,z)
% scale y so that the pair x,y is RPZ-compatible with respect to theta, 
% that is ||x||=||y||=1 and y'*x is a real, positive multiple of 
% exp(i*theta).  absyhx is abs(yhx)
%
%
%   PSAPSR Version 1.4, 2016, see GPL license info below.
%   rpzCompatible.m introduced in PSAPSR Version 1.4.
%
%##########################################################################
%#  PSAPSR: PseudoSpectral Abscissa and PseudoSpectral Radius             #
%#  Copyright (C) 2016 Nicola Guglielmi, Michael Overton, Tim Mitchell    #
%#                                                                        #
%#  This file is part of PSAPSR.                                          #
%#                                                                        #
%#  PSAPSR is free software: you can redistribute it and/or modify it     #
%#  under the terms of the GNU General Public License as published by     #
%#  the Free Software Foundation, either version 3 of the License, or     #
%#  (at your option) any later version.                                   #
%#                                                                        #
%#  PSAPSR is distributed in the hope that it will be useful, but         #
%#  WITHOUT ANY WARRANTY; without even the implied warranty of            #
%#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
%#  GNU General Public License for more details.                          #
%#                                                                        #
%#  You should have received a copy of the GNU General Public License     #
%#  along with this program.  If not, see <http://www.gnu.org/licenses/>. #
%##########################################################################

    theta = -angle(z);

    x = x/norm(x);
    y = y/norm(y);
    yhx = y'*x; 

    if theta == 0 && isreal(yhx)
        % avoid imaginary rounding error
        if yhx < 0
            y = -y; 
            yhx = -yhx;
        end
    elseif theta == -pi && isreal(yhx)
        % no tolerance: 
        %     if z was negative real, theta is -pi to full precision
        % avoid imaginary rounding error
        if yhx > 0
            y = -y;
            yhx = -yhx;
        end
    else
        scalar = exp(1i*(angle(yhx) - theta));
        y = scalar*y; 
        yhx = conj(scalar)*yhx;
    end

    absyhx = abs(yhx);
end