function [s,ind] = sortByModulus(lambda)
%   sortByModulus:
%       Sort complex numbers by modulus and break ties with angles. It
%       firsts sort by angle so that ties have consistent ordering by
%       angle, which puts conjugates with positive real part first.
%   
%       Compared to the PSAPSR v1.2 code, this routine has been updated to 
%       improve code conciseness and efficiency.
%  
%
%   PSAPSR Version 1.4, 2016, see GPL license info below.
%   sortByModulus.m introduced in PSAPSR Version 1.4.
%
%##########################################################################
%#  PSAPSR: PseudoSpectral Abscissa and PseudoSpectral Radius             #
%#  Copyright (C) 2016 Nicola Guglielmi, Michael Overton, Tim Mitchell    #
%#                                                                        #
%#  This file is part of PSAPSR.                                          #
%#                                                                        #
%#  PSAPSR is free software: you can redistribute it and/or modify it     #
%#  under the terms of the GNU General Public License as published by     #
%#  the Free Software Foundation, either version 3 of the License, or     #
%#  (at your option) any later version.                                   #
%#                                                                        #
%#  PSAPSR is distributed in the hope that it will be useful, but         #
%#  WITHOUT ANY WARRANTY; without even the implied warranty of            #
%#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
%#  GNU General Public License for more details.                          #
%#                                                                        #
%#  You should have received a copy of the GNU General Public License     #
%#  along with this program.  If not, see <http://www.gnu.org/licenses/>. #
%##########################################################################
        
    % first sort by angle so ties have consistent ordering by angle, as
    % will exact conjugates
    [~,angle_indices]   = sort(angle(lambda),'descend');
    lambda              = lambda(angle_indices);
    
    % then put desired values first (sort() is stable)
    [~,indices]         = sort(abs(lambda),'descend');  % largest modulus
       
    ind = angle_indices(indices);
    s   = lambda(indices);
end
